@@ -1,11 +1,16 @@
-ANCHORED = 32768
+#
+# Constants for Gtkinter
+#
+
+#ANCHORED = 32768
 ARROW_DOWN = 1
 ARROW_LEFT = 2
 ARROW_RIGHT = 3
 ARROW_UP = 0
 BASIC = 65536
-BEING_DESTROYED = 2
+#BEING_DESTROYED = 2
 BUTTONBOX_DEFAULT = -1
+BUTTONBOX_DEFAULT_STYLE = 0
 BUTTONBOX_EDGE = 2
 BUTTONBOX_END = 4
 BUTTONBOX_SPREAD = 1
@@ -21,6 +26,7 @@ CENTIMETERS = 2
 CURVE_TYPE_FREE = 2
 CURVE_TYPE_LINEAR = 0
 CURVE_TYPE_SPLINE = 1
+DESTROYED = 1
 DIRECTION_LEFT = 0
 DIRECTION_RIGHT = 1
 DIR_DOWN = 3
@@ -31,29 +37,30 @@ DIR_TAB_FORWARD = 0
 DIR_UP = 2
 EXPAND = 1
 FALSE = 0
+FLOATING = 2
 FILL = 4
-HAS_DEFAULT = 4096
-HAS_FOCUS = 1024
-HAS_GRAB = 262144
-HAS_SHAPE_MASK = 4194304
+HAS_DEFAULT = 16384
+HAS_FOCUS = 4096
+HAS_GRAB = 32768
+#HAS_SHAPE_MASK = 4194304
 INCHES = 1
-IN_CALL = 4
+#IN_CALL = 4
 JUSTIFY_CENTER = 2
 JUSTIFY_FILL = 3
 JUSTIFY_LEFT = 0
 JUSTIFY_RIGHT = 1
 LEFT_RIGHT = 1
-MAPPED = 16
+MAPPED = 128
 MENU_FACTORY_MENU = 0
 MENU_FACTORY_MENU_BAR = 1
 MENU_FACTORY_OPTION_MENU = 2
-NEED_DESTROY = 1
-NO_WINDOW = 512
+#NEED_DESTROY = 1
+NO_WINDOW = 32
 ORIENTATION_HORIZONTAL = 0
 ORIENTATION_VERTICAL = 1
 PACK_END = 1
 PACK_START = 0
-PARENT_SENSITIVE = 256
+PARENT_SENSITIVE = 1024
 PIXELS = 0
 POLICY_ALWAYS = 0
 POLICY_AUTOMATIC = 1
@@ -63,11 +70,15 @@ POS_RIGHT = 1
 POS_TOP = 2
 PREVIEW_COLOR = 0
 PREVIEW_GRAYSCALE = 1
-PROPAGATE_STATE = 16384
+#PROPAGATE_STATE = 16384
+RC_STYLE = 262144
 REALIZED = 64
-REDRAW_PENDING = 524288
-RESIZE_NEEDED = 2097152
-RESIZE_PENDING = 1048576
+#REDRAW_PENDING = 524288
+RESERVED_1 = 4
+RESERVED_2 = 8
+RESERVED_3 = 131072
+#RESIZE_NEEDED = 2097152
+#RESIZE_PENDING = 1048576
 RUN_BOTH = 3
 RUN_FIRST = 1
 RUN_LAST = 2
@@ -82,7 +93,7 @@ SELECTION_BROWSE = 1
 SELECTION_EXTENDED = 3
 SELECTION_MULTIPLE = 2
 SELECTION_SINGLE = 0
-SENSITIVE = 128
+SENSITIVE = 512
 SHADOW_ETCHED_IN = 3
 SHADOW_ETCHED_OUT = 4
 SHADOW_IN = 1
@@ -98,6 +109,7 @@ TOOLBAR_BOTH = 2
 TOOLBAR_ICONS = 0
 TOOLBAR_TEXT = 1
 TOP_BOTTOM = 0
+TOPLEVEL = 16
 TREE_VIEW_ITEM = 1
 TREE_VIEW_LINE = 0
 TROUGH_END = 2
@@ -126,15 +138,19 @@ TYPE_SIGNAL = 18
 TYPE_STRING = 10
 TYPE_UINT = 5
 TYPE_ULONG = 7
-UNMAPPED = 32
+#UNMAPPED = 32
+UPDATE_ALWAYS = 1
 UPDATE_CONTINUOUS = 0
 UPDATE_DELAYED = 2
 UPDATE_DISCONTINUOUS = 1
-USER_STYLE = 131072
-VISIBLE = 8
+UPDATE_IF_VALID = 2
+UPDATE_SNAP_TO_TICKS = 4
+#USER_STYLE = 131072
+VISIBLE = 256
 WINDOW_DIALOG = 1
 WINDOW_POPUP = 2
 WINDOW_TOPLEVEL = 0
 WIN_POS_CENTER = 1
 WIN_POS_MOUSE = 2
 WIN_POS_NONE = 0
+
