@@ -55,7 +55,12 @@ class GtkObject:
 		_gtk.GTK_OBJECT_SET_FLAGS(self._o, flags)
 	def unset_flags(self, flags):
 		_gtk.GTK_OBJECT_UNSET_FLAGS(self._o, flags)
-
+	def set_data(self, key, val):
+		_gtk.gtk_object_set_data(self._o, key, value)
+	def get_data(self, key):
+		return _gtk.gtk_object_get_data(self._o, key)
+	def remove_data(self, key):
+		_gtk.gtk_object_remove_data(self._o)
 	class __cnv:
 		def __init__(self, func):
 			self.func = func
@@ -69,10 +74,21 @@ class GtkObject:
 			return apply(self.func, a)
 	def connect(self, name, f):
 		callback = self.__cnv(f)
-		_gtk.gtk_signal_connect(self._o, name, callback.__call__)
+		return _gtk.gtk_signal_connect(self._o,name,callback.__call__)
+	signal_connect = connect
 	def connect_after(self, name, f):
 		callback = self.__cnv(f)
-		_gtk.gtk_signal_connect_after(self._o, name, callback.__call__)
+		return _gtk.gtk_signal_connect_after(self._o, name,
+						     callback.__call__)
+	signal_connect_after = connect_after
+	def disconnect(self, id):
+		_gtk.gtk_signal_disconnect(self._o, id)
+	def signal_handler_block(self, id):
+		_gtk.gtk_signal_handler_block(self._o, id)
+	def signal_handler_unblock(self, id):
+		_gtk.gtk_signal_handler_unblock(self._o, id)
+	def signal_handlers_destroy(self):
+		_gtk.gtk_signal_handlers_destroy(self._o)
 	def emit_stop_by_name(self, sig):
 		_gtk.gtk_signal_emit_stop_by_name(self._o, sig)
 
@@ -85,7 +101,35 @@ class GtkAdjustment(GtkData):
 			page_size=0, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_adjustment_new(value, lower, upper,
-			step_incr, page_incr, page_size)
+					  step_incr, page_incr, page_size)
+	def __getattr__(self, attr):
+		attrs = {
+		'lower': _gtk.gtk_adjustment_get_lower,
+		'upper': _gtk.gtk_adjustment_get_upper,
+		'value': _gtk.gtk_adjustment_get_value,
+		'step_increment': _gtk.gtk_adjustment_get_step_increment,
+		'page_increment': _gtk.gtk_adjustment_get_page_increment,
+		'page_size': _gtk.gtk_adjustment_get_page_size
+		}
+		if attr in attrs.keys():
+			return attrs[attr](self._o)
+		raise AttributeError, attr
+	def set_value(self, value):
+		_gtk.gtk_adjustment_set_value(self._o, value)
+
+class GtkTooltips(GtkData):
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_tooltips_new()
+	def enable(self):
+		_gtk.gtk_tooltips_enable(self._o)
+	def set_delay(self, delay):
+		_gtk.gtk_tooltips_set_delay(self._o, delay)
+	def set_tip(self, w, tip, tip_private):
+		_gtk.gtk_tooltips_set_tip(self._o, w._o, tip, tip_private)
+	def set_tips(self, w, tip):
+		print "GtkTooltip.set_tips deprecated -- use set_tip instead"
+		self.set_tip(w, tip, tip)
 
 class GtkWidget(GtkObject):
 	def __init__(self, _obj=None):
@@ -103,6 +147,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_draw_default(self._o)
 	def draw_focus(self, obj=None):
 		_gtk.gtk_widget_draw_focus(self._o)
+	def ensure_style(self):
+		_gtk.gtk_widget_ensure_style(self._o)
 	def get_ancestor(self, type):
 		return _obj2inst(_gtk.gtk_widget_get_ancestor(self._o, type))
 	def get_events(self):
@@ -143,6 +189,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_realize(self._o)
 	def reparent(self, new_parent):
 		_gtk.gtk_widget_reparent(self._o, new_parent._o)
+	def restore_default_style(self):
+		_gtk.gtk_widget_restore_default_style(self._o)
 	def set_events(self, events):
 		_gtk.gtk_widget_set_events(self._o, events)
 	def set_extension_events(self, exevents):
@@ -155,6 +203,10 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_set_sensitive(self._o, s)
 	def set_state(self, s):
 		_gtk.gtk_widget_set_state(self._o, s)
+	def set_style(self, style):
+		_gtk.gtk_widget_set_style(self._o, style)
+	def set_rc_style(self):
+		_gtk.gtk_widget_set_rc_style(self._o)
 	def set_uposition(self, x, y):
 		_gtk.gtk_widget_set_uposition(self._o, x, y)
 	def set_usize(self, w, h):
@@ -209,7 +261,7 @@ class GtkBin(GtkContainer):
 class GtkAlignment(GtkBin):
 	def __init__(self, xa=0, ya=0, xs=0, ys=0, _obj=None):
 		if _obj: self._o = _obj; return
-		self._o = _gtk.gtk_alignment_newe(xa, ya, xs, ys)
+		self._o = _gtk.gtk_alignment_new(xa, ya, xs, ys)
 	def set(self, xa, ya, xs, ys):
 		_gtk.gtk_alignment_set(self._o, xa, ya, xs, ys)
 
@@ -341,6 +393,8 @@ class GtkMenuItem(GtkItem):
 		_gtk.gtk_menu_item_deselect(self._o)
 	def activate(self, obj=None):
 		_gtk.gtk_menu_item_activate(self._o)
+	def remove_submenu(self):
+		_gtk.gtk_menu_item_remove_submenu(self._o)
 	def right_justify(self, obj=None):
 		_gtk.gtk_menu_item_right_justify(self._o)
 		
@@ -430,6 +484,10 @@ class GtkWindow(GtkBin):
 		self._o = _gtk.gtk_window_new(type)
 		if title is not None:
 			self.set_title(title)
+	def activate_focus(self, obj=None):
+		_gtk.gtk_window_activate_focus(self._o)
+	def activate_default(self, obj=None):
+		_gtk.gtk_window_activate_default(self._o)
 	def set_title(self, title):
 		_gtk.gtk_window_set_title(self._o, title)
 	def set_focus(self, focus):
@@ -444,6 +502,12 @@ class GtkWindow(GtkBin):
 		_gtk.gtk_window_remove_accelerator_table(self._o, t._at)
 	def position(self, pos):
 		_gtk.gtk_window_position(self._o, pos)
+	def set_wmclass(self, wmc_name, wmc_class):
+		_gtk.gtk_window_set_wmclass(self._o, wmc_name, wmc_class)
+	def set_icon(self, pixmap):
+		_gtk.gtk_window_set_icon(self._o, pixmap._o)
+	def set_icon_name(self, name):
+		_gtk.gtk_window_set_icon_name(self._o, name)
 
 class GtkColorSelectionDialog(GtkWindow):
 	def __init__(self, name="", _obj=None):
@@ -549,10 +613,14 @@ class GtkStatusbar(GtkHBox):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_statusbar_new()
-	def pop(self, sid):
-		_gtk.gtk_statusbar_pop(self._o, sid)
-	def push(self, text):
-		return _gtk.gtk_statusbar_push(self._o, text)
+	def get_context_id(self, desc):
+		return _gtk.gtk_statusbar_get_context_id(self._o, desc)
+	def pop(self, cid):
+		_gtk.gtk_statusbar_pop(self._o, cid)
+	def push(self, cid, text):
+		return _gtk.gtk_statusbar_push(self._o, cid, text)
+	def remove(self, cid, msg_id):
+		_gtk.gtk_statusbar_remove(self._o, cid, msg_id)
 
 class GtkVBox(GtkBox):
 	def __init__(self, homogeneous=0, spacing=0, _obj=None):
@@ -639,7 +707,7 @@ class GtkCList(GtkContainer):
 		else:
 			self._o = _gtk.gtk_clist_new_with_titles(cols, titles)
 	def append(self, values):
-		_gtk.gtk_clist_append(self._o, values)
+		return _gtk.gtk_clist_append(self._o, values)
 	def clear(self, obj=None):
 		_gtk.gtk_clist_clear(self._o)
 	def column_title_active(self, col):
@@ -656,6 +724,10 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_column_titles_show(self._o)
 	def freeze(self, obj=None):
 		_gtk.gtk_clist_freeze(self._o)
+	def get_cell_type(self, r, c):
+		return _gtk.gtk_clist_get_cell_type(self._o, r, c)
+	def get_text(self, r, c):
+		return _gtk.gtk_clist_get_text(self._o, r, c)
 	def insert(self, row, values):
 		_gtk.gtk_clist_insert(self._o, row, values)
 	def moveto(self, row=-1, col=-1, row_align=0.5, col_align=0.5):
@@ -668,6 +740,8 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_set_background(self._o, row, colour)
 	def set_border(self, border):
 		_gtk.gtk_clist_set_border(self._o, border)
+	def set_column_title(self, col, title):
+		_gtk.gtk_clist_set_column_title(self._o, col, title)
 	def set_column_widget(self, col, w):
 		_gtk.gtk_clist_set_column_widget(self._o, col, w._o)
 	def set_column_justification(self, col, just):
@@ -686,6 +760,10 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_set_selection_mode(self._o, mode)
 	def set_text(self, r, c, text):
 		_gtk.gtk_clist_set_text(self._o, r, c, text)
+	def set_pixmap(self, r, c, pixmap):
+		_gtk.gtk_clist_set_pixmap(self._o, r, c, pixmap._o)
+	def set_pixtext(self, r, c, text, spacing, pixmap):
+		_gtk.gtk_clist_set_pixtext(self._o,r,c,text,spacing,pixmap._o)
 	def thaw(self):
 		_gtk.gtk_clist_thaw(self._o)
 	def unselect_row(self, row, col):
@@ -772,6 +850,10 @@ class GtkMenu(GtkMenuShell):
 		_gtk.gtk_menu_popdown(self._o)
 	def get_active(self):
 		return _obj2inst(_gtk.gtk_menu_get_active(self._o))
+	def get_attach_widget(self):
+		return _obj2inst(_gtk.gtk_menu_get_attach_widget(self._o))
+	def detach(self):
+		_gtk.gtk_menu_detach(self._o)
 	def set_active(self, index):
 		_gtk.gtk_menu_set_active(self._o, index)
 	def set_accelerator_table(self, table):
@@ -783,26 +865,43 @@ class GtkNotebook(GtkContainer):
 		self._o = _gtk.gtk_notebook_new()
 	def append_page(self, child, tab):
 		_gtk.gtk_notebook_append_page(self._o, child._o, tab._o)
+	def append_page_menu(self, child, tab, ml):
+		_gtk.gtk_notebook_append_page_menu(self._o, child._o, tab._o,
+						   ml._o)
 	def prepend_page(self, child, tab):
 		_gtk.gtk_notebook_prepend_page(self._o, child._o, tab._o)
+	def prepend_page_menu(self, child, tab, ml):
+		_gtk.gtk_notebook_prepend_page_menu(self._o, child._o, tab._o,
+						    ml._o)
 	def insert_page(self, child, tab, pos):
 		_gtk.gtk_notebook_insert_page(self._o, child._o, tab._o, pos)
+	def insert_page_menu(self, child, tab, ml, pos):
+		_gtk.gtk_notebook_insert_page_menu(self._o, child._o, tab._o,
+						   ml._o, pos)
 	def remove_page(self, pos):
 		_gtk.gtk_notebook_remove_page(self._o, pos)
 	def current_page(self):
 		return _gtk.gtk_notebook_current_page(self._o)
 	def set_page(self, pos):
 		_gtk.gtk_notebook_set_page(self._o, pos)
-	def next_page(self, obj):
+	def next_page(self, obj=None):
 		_gtk.gtk_notebook_next_page(self._o)
-	def prev_page(self, obj):
+	def prev_page(self, obj=None):
 		_gtk.gtk_notebook_prev_page(self._o)
+	def set_tab_border(self, border):
+		_gtk.gtk_notebook_set_tab_border(self._o, border)
 	def set_tab_pos(self, pos):
 		_gtk.gtk_notebook_set_tab_pos(self._o, pos)
+	def set_scrollable(self, scrollable):
+		_gtk.gtk_notebook_set_scrollable(self._o, scrollable)
 	def set_show_tabs(self, show):
 		_gtk.gtk_notebook_set_show_tabs(self._o, show)
 	def set_show_border(self, show):
 		_gtk.gtk_notebook_set_show_border(self._o, show)
+	def popup_enable(self, obj=None):
+		_gtk.gtk_notebook_popup_enable(self._o)
+	def popup_disable(self, obj=None):
+		_gtk.gtk_notebook_popup_disable(self._o)
 
 class GtkPaned(GtkContainer):
 	def __init__(self, _obj=None):
@@ -902,27 +1001,27 @@ class GtkToolbar(GtkContainer):
 		     style=TOOLBAR_ICONS, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_toolbar_new(orientation, style)
-        def append_item(self, text, tooltip, icon, callback):
-		_gtk.gtk_toolbar_append_item(self._o, text, tooltip, icon._o,
-					     callback)
+        def append_item(self, text, tooltip, tp, icon, callback):
+		_gtk.gtk_toolbar_append_item(self._o, text, tooltip, tp,
+					     icon._o, callback)
 	def append_space(self):
 		_gtk.gtk_toolbar_append_space(self._o)
-	def append_widget(self, w, tooltip):
-		_gtk.gtk_toolbar_append_widget(self._o, w._o, tooltip)
-	def insert_item(self, text, tooltip, icon, callback, pos):
-		_gtk.gtk_toolbar_insert_item(self._o, text, tooltip, icon._o,
-					     callback, pos)
+	def append_widget(self, w, tooltip, tp):
+		_gtk.gtk_toolbar_append_widget(self._o, w._o, tooltip, tp)
+	def insert_item(self, text, tooltip, tp, icon, callback, pos):
+		_gtk.gtk_toolbar_insert_item(self._o, text, tooltip, tp,
+					     icon._o, callback, pos)
 	def insert_space(self, pos):
 		_gtk.gtk_toolbar_insert_space(self._o, pos)
-	def insert_widget(self, w, tooltip, pos):
-		_gtk.gtk_toolbar_insert_widget(self._o, w._o, tooltip, pos)
-	def prepend_item(self, text, tooltip, icon, callback):
-		_gtk.gtk_toolbar_prepend_item(self._o, text, tooltip, icon._o,
-					      callback)
+	def insert_widget(self, w, tooltip, tp, pos):
+		_gtk.gtk_toolbar_insert_widget(self._o, w._o, tooltip, tp, pos)
+	def prepend_item(self, text, tooltip, tp, icon, callback):
+		_gtk.gtk_toolbar_prepend_item(self._o, text, tooltip, tp,
+					      icon._o, callback)
 	def prepend_space(self):
 		_gtk.gtk_toolbar_prepend_space(self._o)
-	def prepend_widget(self, w, tooltip):
-		_gtk.gtk_toolbar_prepend_widget(self._o, w._o, tooltip)
+	def prepend_widget(self, w, tooltip, tp):
+		_gtk.gtk_toolbar_prepend_widget(self._o, w._o, tooltip, tp)
        	def set_orientation(self, orientation):
 		_gtk.gtk_toolbar_set_orientation(self._o, orientation)
 	def set_style(self, style):
@@ -952,7 +1051,31 @@ class GtkCurve(GtkDrawingArea):
 	def set_curve_type(self, tp):
 		_gtk.gtk_curve_set_curve_type(self._o, tp)
 
-class GtkEntry(GtkWidget):
+class GtkEditable(GtkWidget):
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+	def select_region(self, start, end):
+		_gtk.gtk_editable_select_region(self._o, start, end)
+	def insert_text(self, new_text):
+		return _gtk.gtk_editable_insert_text(self._o, new_text)
+	def delete_text(self, start, end):
+		_gtk.gtk_editable_delete_text(self._o, start, end)
+	def get_chars(self, start, end):
+		return _gtk.gtk_editable_get_chars(self._o, start, end)
+	def cut_clipboard(self, time):
+		_gtk.gtk_editable_cut_clipboard(self._o, time)
+	def copy_clipboard(self, time):
+		_gtk.gtk_editable_copy_clipboard(self._o, time)
+	def paste_clipboard(self, time):
+		_gtk.gtk_editable_paste_clipboard(self._o, time)
+	def claim_selection(self, claim, time):
+		_gtk.gtk_editable_claim_selection(self._o, claim, time)
+	def delete_selection(self):
+		_gtk.gtk_editable_delete_selection(self._o)
+	def changed(self):
+		_gtk.gtk_editable_changed(self._o)
+
+class GtkEntry(GtkEditable):
 	def __init__(self, maxlen=-1, _obj=None):
 		if _obj: self._o = _obj; return
 		if maxlen == -1:
@@ -978,6 +1101,66 @@ class GtkEntry(GtkWidget):
 	def set_max_length(self, max):
 		_gtk.gtk_entry_set_max_length(self._o, max)
 
+class GtkSpinButton(GtkEntry):
+	def __init__(self, adj=None, climb_rate=1, digits=1, _obj=None):
+		if _obj: self._o = _obj; return
+		if adj:
+			self._o = _gtk.gtk_spin_button_new(adj, climb_rate,
+							   digits)
+		else:
+			self._o = _gtk.gtk_spin_button_new_no_adj(climb_rate,
+								  digits)
+	def set_adjustment(self, adj):
+		_gtk.gtk_spin_button_set_adjustment(self._o, adj._o)
+	def get_adjustment(self):
+		return _obj2inst(_gtk.gtk_spin_button_get_adjustment(sel._o))
+	def set_digits(self, digits):
+		_gtk.gtk_spin_button_set_digits(self._o, digits)
+	def get_value_as_float(self):
+		return _gtk.gtk_spin_button_get_value_as_float(self._o)
+	def get_value_as_int(self):
+		return _gtk.gtk_spin_button_get_value_as_int(self._o)
+	get_value = get_value_as_float
+	def set_value(self, val):
+		_gtk.gtk_spin_button_set_value(self._o, val)
+	def set_update_policy(self, pol):
+		_gtk.gtk_spin_button_set_update_policy(self._o, pol)
+
+class GtkText(GtkEditable):
+	def __init__(self, hadj=None, vadj=None, _obj=None):
+		if _obj: self._o = _obj; return
+		if not (hadj or vadj):
+			self._o = _gtk.gtk_text_new()
+		else:
+			self._o = _gtk.gtk_text_new(hadj._o, vadj._o)
+	def set_editable(self, editable):
+		_gtk.gtk_text_set_editable(self._o, editable)
+	def set_adjustments(self, hadj, vadj):
+		_gtk.gtk_text_set_adjustments(self._o, hadj._o, vadj._o)
+	def get_hadjustment(self):
+		return _obj2inst(_gtk.gtk_text_get_hadjustment(self._o))
+	def get_vadjustment(self):
+		return _obj2inst(_gtk.gtk_text_get_vadjustment(self._o))
+	def set_point(self, point):
+		_gtk.gtk_text_set_point(self._o, point)
+	def get_point(self):
+		return _gtk.gtk_text_get_point(self._o)
+	def get_length(self):
+		return _gtk.gtk_text_get_length(self._o)
+	def freeze(self, obj=None):
+		_gtk.gtk_text_freeze(self._o)
+	def thaw(self, obj=None):
+		_gtk.gtk_text_thaw(self._o)
+	def insert(self, font, fg, bg, string):
+		_gtk.gtk_text_insert(self._o, font, fg, bg, string,
+				     len(string))
+	def insert_defaults(self, chars):
+		_gtk.gtk_text_insert_defaults(self._o, chars)
+	def backward_delete(self, nchars):
+		_gtk.gtk_text_backward_delete(self._o, nchars)
+	def forward_delete(self, nchars):
+		_gtk.gtk_text_forward_delete(self._o, nchars)
+
 class GtkMisc(GtkWidget):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
@@ -987,7 +1170,7 @@ class GtkMisc(GtkWidget):
 		_gtk.gtk_misc_set_padding(self._o, xp, yp)
 
 class GtkArrow(GtkMisc):
-	def __init__(self, at=DIR_RIGHT, st=SHADOW_OUT, _obj=None):
+	def __init__(self, at=ARROW_RIGHT, st=SHADOW_OUT, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_arrow_new(at, st)
 	def set(self, at, st):
@@ -1017,6 +1200,19 @@ class GtkLabel(GtkMisc):
 	def get(self):
 		return _gtk.gtk_label_get(self._o)
 
+class GtkTipsQuery(GtkLabel):
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_tips_query_new()
+	def start_query(self, obj=None):
+		_gtk.gtk_tips_query_start_query(self._o)
+	def stop_query(self, obj=None):
+		_gtk.gtk_tips_query_stop_query(self._o)
+	def set_caller(self, caller):
+		_gtk.gtk_tips_query_set_caller(self._o, caller._o)
+	def set_labels(self, inactive, no_tip):
+		_gtk.gtk_tips_query_set_labels(self._o, inactive, no_tip)
+
 class GtkPreview(GtkWidget):
 	def uninit(self):
 		_gtk.gtk_preview_uninit()
@@ -1163,40 +1359,6 @@ class GtkVSeparator(GtkSeparator):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_vseparator_new()
 
-class GtkText(GtkWidget):
-	def __init__(self, hadj=None, vadj=None, _obj=None):
-		if _obj: self._o = _obj; return
-		if not (hadj or vadj):
-			self._o = _gtk.gtk_text_new()
-		else:
-			self._o = _gtk.gtk_text_new(hadj._o, vadj._o)
-	def set_editable(self, editable):
-		_gtk.gtk_text_set_editable(self._o, editable)
-	def set_adjustments(self, hadj, vadj):
-		_gtk.gtk_text_set_adjustments(self._o, hadj._o, vadj._o)
-	def get_hadjustment(self):
-		return _obj2inst(_gtk.gtk_text_get_hadjustment(self._o))
-	def get_vadjustment(self):
-		return _obj2inst(_gtk.gtk_text_get_vadjustment(self._o))
-	def set_point(self, point):
-		_gtk.gtk_text_set_point(self._o, point)
-	def get_point(self):
-		return _gtk.gtk_text_get_point(self._o)
-	def get_length(self):
-		return _gtk.gtk_text_get_length(self._o)
-	def freeze(self, obj=None):
-		_gtk.gtk_text_freeze(self._o)
-	def thaw(self, obj=None):
-		_gtk.gtk_text_thaw(self._o)
-	def insert(self, font, fg, bg, string):
-		_gtk.gtk_text_insert(self._o, font, fg, bg, string,
-				     len(string))
-	def insert_defaults(self, chars):
-		_gtk.gtk_text_insert_defaults(self._o, chars)
-	def backward_delete(self, nchars):
-		_gtk.gtk_text_backward_delete(self._o, nchars)
-	def forward_delete(self, nchars):
-		_gtk.gtk_text_forward_delete(self._o, nchars)
 
 _name2cls = {}
 _supported = map(lambda x: eval(x), filter(lambda x: x[:3] == 'Gtk', dir()))
@@ -1222,20 +1384,24 @@ class GtkAcceleratorTable:
 	def set_mod_mask(self, mod_mask):
 		_gtk.gtk_accelerator_table_set_mod_mask(self._at, mod_mask)
 
-class GtkTooltips:
-	def __init__(self, _obj=None):
-		if _obj: self._o = _obj; return
-		self._tt = _gtk.gtk_tooltips_new()
-	def enable(self):
-		_gtk.gtk_tooltips_enable(self._tt)
-	def set_delay(self, delay):
-		_gtk.gtk_tooltips_set_delay(self._tt, delay)
-	def set_tips(self, w, tip):
-		_gtk.gtk_tooltips_set_tips(self._tt, w._o, tip)
-
 def _obj2inst(obj):
 	objname = _gtk.gtk_type_name(_gtk.GTK_OBJECT_TYPE(obj))
-	return _name2cls[objname](_obj=obj)
+	if _name2cls.has_key(objname):
+		return _name2cls[objname](_obj=obj)
+	# if I don't know what the object is, guess
+	elif _gtk.GTK_IS_BOX(obj):
+		return GtkBox(_obj=obj)
+	elif _gtk.GTK_IS_BIN(obj):
+		return GtkBin(_obj=obj)
+	elif _gtk.GTK_IS_WINDOW(obj):
+		return GtkWindow(_obj=obj)
+	elif _gtk.GTK_IS_CONTAINER(obj):
+		return GtkContainer(_obj=obj)
+	elif _gtk.GTK_IS_WIDGET(obj):
+		return GtkWidget(_obj=obj)
+	else:
+		return GtkObject(_obj=obj)
+		
 
 def _filtprops(props):
 	for k in props.keys():
@@ -1253,6 +1419,8 @@ def mainloop():
 	_gtk.gtk_main()
 def mainquit(*args):
 	_gtk.gtk_main_quit()
+def mainiteration(block=TRUE):
+	_gtk.gtk_main_iteration(block)
 def idle_add(callback):
 	return _gtk.gtk_idle_add(callback)
 def idle_remove(tag):
