@@ -247,19 +247,24 @@ def make_toolbar(win):
 			print "Hello"
 
 		toolbar.append_item("Horizontal", "Horizontal toolbar layout",
+				    "Horizontal toolbar layout",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_horizontal)
 		toolbar.append_item("Vertical", "Vertical toolbar layout",
+				    "Vertical toolbar layout",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_vertical)
 		toolbar.append_space()
 		toolbar.append_item("Icons", "Only show toolbar icons",
+				    "Only Icons",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_icons)
 		toolbar.append_item("Text", "Only show toolbar text",
+				    "Only Text",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_text)
 		toolbar.append_item("Both", "Show toolbar icons and text",
+				    "Both Text and Icons",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_both)
 		toolbar.append_space()
@@ -270,16 +275,20 @@ def make_toolbar(win):
 
 		toolbar.append_space()
 		toolbar.append_item("Small", "Use small spaces",
+				    "Small spaces",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_small_space)
 		toolbar.append_item("Big", "Use big spaces",
+				    "Big spaces",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_big_space)
 		toolbar.append_space()
 		toolbar.append_item("Enable", "Enable tooltips",
+				    "Enable tooltips",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_enable)
 		toolbar.append_item("Disable", "Disable tooltips",
+				    "Disable tooltips",
 				    GtkPixmap(win, "test.xpm", bg),
 				    set_toolbar_disable)
 		return toolbar
@@ -442,7 +451,6 @@ def create_tooltips(_button):
 		win.set_title("tooltips")
 
 		tooltips = GtkTooltips()
-		win.tooltips = tooltips # keep a reference with the window
 
 		box1 = GtkVBox()
 		win.add(box1)
@@ -456,17 +464,17 @@ def create_tooltips(_button):
 		button = GtkToggleButton("button1")
 		box2.pack_start(button)
 		button.show()
-		tooltips.set_tips(button, "This is button 1")
+		tooltips.set_tip(button, "This is button 1", "button 1")
 
 		button = GtkToggleButton("button2")
 		box2.pack_start(button)
 		button.show()
-		tooltips.set_tips(button, "This is button 2")
+		tooltips.set_tip(button, "This is button 2", "button 2")
 
 		button = GtkToggleButton("button3")
 		box2.pack_start(button)
 		button.show()
-		tooltips.set_tips(button, "This is button 3.  This is also a really long tooltip which probably won't fit on a single line and will therefore need to be wrapped.  Hopefully the wrapping will work correctly.")
+		tooltips.set_tip(button, "This is button 3.  This is also a really long tooltip which probably won't fit on a single line and will therefore need to be wrapped.  Hopefully the wrapping will work correctly.", "long")
 
 		separator = GtkHSeparator()
 		box1.pack_start(separator, expand=FALSE)
@@ -484,7 +492,8 @@ def create_tooltips(_button):
 		button.grab_default()
 		button.show()
 
-		tooltips.set_tips(button, "Push this button to close window")
+		tooltips.set_tip(button, "Push this button to close window",
+				 "push")
 		tooltips.enable()
 	wins["tooltips"].show()
 
